stringtools.string_to_strict_directory_name
===========================================

.. autofunction:: abjad.tools.stringtools.string_to_strict_directory_name.string_to_strict_directory_name
   :noindex:
